==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/TelephonyChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property apiConfigurations The list of Telephony api configuration
 * @property cognitiveServiceRegion The extensionKey2
 * @property cognitiveServiceSubscriptionKey The extensionKey1
 * @property defaultLocale The default locale of the channel
 * @property isEnabled Whether the channel is enabled
 * @property phoneNumbers The list of Telephony phone numbers
 * @property premiumSKU The premium SKU applied to the channel
 */
public data class TelephonyChannelPropertiesArgs(
    public val apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null,
    public val cognitiveServiceRegion: Output<String>? = null,
    public val cognitiveServiceSubscriptionKey: Output<String>? = null,
    public val defaultLocale: Output<String>? = null,
    public val isEnabled: Output<Boolean>? = null,
    public val phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null,
    public val premiumSKU: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder()
            .apiConfigurations(
                apiConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .cognitiveServiceRegion(cognitiveServiceRegion?.applyValue({ args0 -> args0 }))
            .cognitiveServiceSubscriptionKey(cognitiveServiceSubscriptionKey?.applyValue({ args0 -> args0 }))
            .defaultLocale(defaultLocale?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 }))
            .phoneNumbers(
                phoneNumbers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .premiumSKU(premiumSKU?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TelephonyChannelPropertiesArgs].
 */
@PulumiTagMarker
public class TelephonyChannelPropertiesArgsBuilder internal constructor() {
    private var apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null

    private var cognitiveServiceRegion: Output<String>? = null

    private var cognitiveServiceSubscriptionKey: Output<String>? = null

    private var defaultLocale: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null

    private var premiumSKU: Output<String>? = null

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("tkvjnwriovrkxutw")
    public suspend
    fun apiConfigurations(`value`: Output<List<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = value
    }

    @JvmName("vlhrepninfvnurio")
    public suspend fun apiConfigurations(
        vararg
        values: Output<TelephonyChannelResourceApiConfigurationArgs>,
    ) {
        this.apiConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("mervjkrsbaumhkqn")
    public suspend
    fun apiConfigurations(values: List<Output<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = Output.all(values)
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("xmiqodosyecvgcdh")
    public suspend fun cognitiveServiceRegion(`value`: Output<String>) {
        this.cognitiveServiceRegion = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("aifptgfdowtowmjm")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: Output<String>) {
        this.cognitiveServiceSubscriptionKey = value
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("rlxafyrjerssenrb")
    public suspend fun defaultLocale(`value`: Output<String>) {
        this.defaultLocale = value
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("wyrwlmaicvblkqet")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("gitoysrxxwrnsrka")
    public suspend fun phoneNumbers(`value`: Output<List<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = value
    }

    @JvmName("qyjbesebhricoihi")
    public suspend fun phoneNumbers(vararg values: Output<TelephonyPhoneNumbersArgs>) {
        this.phoneNumbers = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("yvbtiointsdacmhm")
    public suspend fun phoneNumbers(values: List<Output<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = Output.all(values)
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("ismurwchfjgkfwlq")
    public suspend fun premiumSKU(`value`: Output<String>) {
        this.premiumSKU = value
    }

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("vchthislphulgcyi")
    public suspend
    fun apiConfigurations(`value`: List<TelephonyChannelResourceApiConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("xesqolqnannaeypa")
    public suspend
    fun apiConfigurations(argument: List<suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("jcmatcykagghseyo")
    public suspend fun apiConfigurations(
        vararg
        argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("ysoqonqfbipohmfj")
    public suspend
    fun apiConfigurations(argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("rybjcbxbrwkrptfw")
    public suspend fun apiConfigurations(
        vararg
        values: TelephonyChannelResourceApiConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("ojrmqutmxkxbybxt")
    public suspend fun cognitiveServiceRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceRegion = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("qxxfcnrnwynbowsy")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceSubscriptionKey = mapped
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("gvpecfykwqulnqtn")
    public suspend fun defaultLocale(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultLocale = mapped
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("vhwgwpdbqbbnhrht")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("mwvokjgywggfrupt")
    public suspend fun phoneNumbers(`value`: List<TelephonyPhoneNumbersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("moyeyqedfjvfvsdf")
    public suspend
    fun phoneNumbers(argument: List<suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("gffupxgnadlmsjkx")
    public suspend fun phoneNumbers(
        vararg
        argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("ickttliutohgdfwd")
    public suspend fun phoneNumbers(argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TelephonyPhoneNumbersArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("nsxjcexgbgjakxbv")
    public suspend fun phoneNumbers(vararg values: TelephonyPhoneNumbersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("hkdeldvfdmtxurge")
    public suspend fun premiumSKU(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.premiumSKU = mapped
    }

    internal fun build(): TelephonyChannelPropertiesArgs = TelephonyChannelPropertiesArgs(
        apiConfigurations = apiConfigurations,
        cognitiveServiceRegion = cognitiveServiceRegion,
        cognitiveServiceSubscriptionKey = cognitiveServiceSubscriptionKey,
        defaultLocale = defaultLocale,
        isEnabled = isEnabled,
        phoneNumbers = phoneNumbers,
        premiumSKU = premiumSKU,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/TelephonyChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property apiConfigurations The list of Telephony api configuration
 * @property cognitiveServiceRegion The extensionKey2
 * @property cognitiveServiceSubscriptionKey The extensionKey1
 * @property defaultLocale The default locale of the channel
 * @property isEnabled Whether the channel is enabled
 * @property phoneNumbers The list of Telephony phone numbers
 * @property premiumSKU The premium SKU applied to the channel
 */
public data class TelephonyChannelPropertiesArgs(
    public val apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null,
    public val cognitiveServiceRegion: Output<String>? = null,
    public val cognitiveServiceSubscriptionKey: Output<String>? = null,
    public val defaultLocale: Output<String>? = null,
    public val isEnabled: Output<Boolean>? = null,
    public val phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null,
    public val premiumSKU: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder()
            .apiConfigurations(
                apiConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .cognitiveServiceRegion(cognitiveServiceRegion?.applyValue({ args0 -> args0 }))
            .cognitiveServiceSubscriptionKey(cognitiveServiceSubscriptionKey?.applyValue({ args0 -> args0 }))
            .defaultLocale(defaultLocale?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 }))
            .phoneNumbers(
                phoneNumbers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .premiumSKU(premiumSKU?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TelephonyChannelPropertiesArgs].
 */
@PulumiTagMarker
public class TelephonyChannelPropertiesArgsBuilder internal constructor() {
    private var apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null

    private var cognitiveServiceRegion: Output<String>? = null

    private var cognitiveServiceSubscriptionKey: Output<String>? = null

    private var defaultLocale: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null

    private var premiumSKU: Output<String>? = null

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("pfitvlqdjksuodfr")
    public suspend
    fun apiConfigurations(`value`: Output<List<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = value
    }

    @JvmName("rmliufhjajfvmoed")
    public suspend fun apiConfigurations(
        vararg
        values: Output<TelephonyChannelResourceApiConfigurationArgs>,
    ) {
        this.apiConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("rsqwdjovrrrsmlqv")
    public suspend
    fun apiConfigurations(values: List<Output<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = Output.all(values)
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("kwteyqfbdxmkknfh")
    public suspend fun cognitiveServiceRegion(`value`: Output<String>) {
        this.cognitiveServiceRegion = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("hilowdmxaxxunhdy")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: Output<String>) {
        this.cognitiveServiceSubscriptionKey = value
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("mhooyewfsdjyqrkm")
    public suspend fun defaultLocale(`value`: Output<String>) {
        this.defaultLocale = value
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("erkpkwyvmxkaogsv")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("averwqbmsgcjdiuv")
    public suspend fun phoneNumbers(`value`: Output<List<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = value
    }

    @JvmName("ueurndpmnymxexav")
    public suspend fun phoneNumbers(vararg values: Output<TelephonyPhoneNumbersArgs>) {
        this.phoneNumbers = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("dcbppahhgsfnasos")
    public suspend fun phoneNumbers(values: List<Output<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = Output.all(values)
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("essmdippkmsdetur")
    public suspend fun premiumSKU(`value`: Output<String>) {
        this.premiumSKU = value
    }

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("ggpgmaqvvqddicix")
    public suspend
    fun apiConfigurations(`value`: List<TelephonyChannelResourceApiConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("mwvtdskngtepqadm")
    public suspend
    fun apiConfigurations(argument: List<suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("haqndhqbipfbhudm")
    public suspend fun apiConfigurations(
        vararg
        argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("cgohrtmysccrqksj")
    public suspend
    fun apiConfigurations(argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("vmcqrkssmatepvfg")
    public suspend fun apiConfigurations(
        vararg
        values: TelephonyChannelResourceApiConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("quhvhsdseaortjuc")
    public suspend fun cognitiveServiceRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceRegion = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("igvrrwekkrlxqhwk")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceSubscriptionKey = mapped
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("ridxbtydsoqkqtpx")
    public suspend fun defaultLocale(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultLocale = mapped
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("exrfswevribrupbx")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("fvgaehswavprnngw")
    public suspend fun phoneNumbers(`value`: List<TelephonyPhoneNumbersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("omqyumconkuvecps")
    public suspend
    fun phoneNumbers(argument: List<suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("brxuqugxxwnkkyoc")
    public suspend fun phoneNumbers(
        vararg
        argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("ypwattdkevngoing")
    public suspend fun phoneNumbers(argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TelephonyPhoneNumbersArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("ypunptlvasmteobu")
    public suspend fun phoneNumbers(vararg values: TelephonyPhoneNumbersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("vivrpfyqbigjmxku")
    public suspend fun premiumSKU(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.premiumSKU = mapped
    }

    internal fun build(): TelephonyChannelPropertiesArgs = TelephonyChannelPropertiesArgs(
        apiConfigurations = apiConfigurations,
        cognitiveServiceRegion = cognitiveServiceRegion,
        cognitiveServiceSubscriptionKey = cognitiveServiceSubscriptionKey,
        defaultLocale = defaultLocale,
        isEnabled = isEnabled,
        phoneNumbers = phoneNumbers,
        premiumSKU = premiumSKU,
    )
}
